netapp_ontap.models.firmware API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Firmware object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster_fw_progress GET`

    The cluster_fw_progress field of the firmware.

  `disk GET`

    The disk field of the firmware.

  `dqp GET`

    The dqp field of the firmware.

  `shelf GET`

    The shelf field of the firmware.

  `sp_bmc GET`

    The sp_bmc field of the firmware.